"use strict";
var P = require("bluebird");
var websocket_1 = require("websocket");
var system_logger_1 = require("../../logging/system-logger");
var StreamPlatformClient = (function () {
    function StreamPlatformClient(host, port, options) {
        this.host = host;
        this.port = port;
        this.options = options || { secure: false, version: 1 };
    }
    StreamPlatformClient.prototype.initialize = function () {
        var _this = this;
        this.logger = system_logger_1.SystemLogger.get();
        // Create the web socket
        this.socket = new websocket_1.client();
        this.conn = new P(function (resolve, reject) {
            _this.connResolver = resolve;
            _this.connRejecter = reject;
        });
        this.socket.on('connectFailed', function (error) {
            _this.logger.error("Platform stream connection failed:", error);
            _this.connRejecter(error);
        });
        this.socket.on('connect', function (conn) {
            _this.logger.debug("Connected to stream");
            _this.connResolver(conn);
        });
    };
    StreamPlatformClient.prototype.connection = function () {
        return this.conn;
    };
    StreamPlatformClient.prototype.resolveService = function (query) {
        return undefined;
    };
    StreamPlatformClient.prototype.send = function (request) {
        return undefined;
    };
    StreamPlatformClient.prototype.exec = function (request) {
        return undefined;
    };
    StreamPlatformClient.prototype.broadcast = function (request) {
        return undefined;
    };
    StreamPlatformClient.prototype.head = function (request) {
        return undefined;
    };
    return StreamPlatformClient;
}());
exports.StreamPlatformClient = StreamPlatformClient;

//# sourceMappingURL=stream-platform-client.js.map
